Package: megadepth
Title: megadepth: BigWig and BAM related utilities
Version: 1.16.0
Date: 2021-08-05
Authors@R: 
    c(
    person(
        "Leonardo", "Collado-Torres", role = c("aut"), 
        email = "lcolladotor@gmail.com",
        comment = c(ORCID = "0000-0003-2140-308X")
    ),
    person(
        given = "David",
        family = "Zhang",
        role = c("aut", "cre"),
        email = "david.zhang.12@ucl.ac.uk",
        comment = c(ORCID = "0000-0003-2382-8460")
    ))
Description: This package provides an R interface to Megadepth by Christopher
    Wilks available at https://github.com/ChristopherWilks/megadepth. It is
    particularly useful for computing the coverage of a set of genomic regions
    across bigWig or BAM files. With this package, you can build base-pair
    coverage matrices for regions or annotations of your choice from BigWig
    files. Megadepth was used to create the raw files provided by
    https://bioconductor.org/packages/recount3.
License: Artistic-2.0
URL: https://github.com/LieberInstitute/megadepth
BugReports: https://support.bioconductor.org/t/megadepth
biocViews: Software, Coverage, DataImport, Transcriptomics, RNASeq,
        Preprocessing
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Suggests: covr, knitr, BiocStyle, sessioninfo, rmarkdown, rtracklayer,
        derfinder, GenomeInfoDb, tools, RefManageR, testthat
SystemRequirements: megadepth
        (<https://github.com/ChristopherWilks/megadepth>)
VignetteBuilder: knitr
Imports: xfun, utils, fs, GenomicRanges, readr, cmdfun, dplyr, magrittr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/megadepth
git_branch: RELEASE_3_20
git_last_commit: d7f5e2d
git_last_commit_date: 2024-10-29
Repository: Bioconductor 3.20
Date/Publication: 2024-10-29
NeedsCompilation: no
Packaged: 2024-10-30 01:28:03 UTC; biocbuild
Author: Leonardo Collado-Torres [aut] (<https://orcid.org/0000-0003-2140-308X>),
  David Zhang [aut, cre] (<https://orcid.org/0000-0003-2382-8460>)
Maintainer: David Zhang <david.zhang.12@ucl.ac.uk>
